stackinput

package
v0.3.60 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 12, 2026 License: Apache-2.0 Imports: 11 Imported by: 0

Documentation

Index

Constants

const ProviderConfigKey = "provider_config"

ProviderConfigKey is the key used in stack input for provider configuration.

Variables

This section is empty.

Functions

func BuildStackInputYaml

func BuildStackInputYaml(
	manifestObject proto.Message,
	providerConfig *stackinputproviderconfig.ProviderConfig,
) (string, error)

BuildStackInputYaml builds stack input YAML from a manifest and provider config. The provider config path is read from the unified ProviderConfig struct.

func ExtractManifestFromBytes

func ExtractManifestFromBytes(stackInputBytes []byte) (manifestPath string, err error)

ExtractManifestFromBytes extracts the manifest from stack input YAML bytes. This enables reading stack input from sources other than files (e.g., clipboard). The stack input must contain a "target" field with the manifest content. Returns the path to the temporary manifest file.

func ExtractManifestFromStackInput

func ExtractManifestFromStackInput(stackInputPath string) (manifestPath string, err error)

ExtractManifestFromStackInput reads a stack input YAML file, extracts the "target" field, and writes it to a temporary file. Returns the path to the temporary manifest file.

func IsStackInput

func IsStackInput(content []byte) bool

IsStackInput checks if the given YAML bytes represent a stack input (has "target" key at root).

func LoadProviderConfig

func LoadProviderConfig(
	stackInputContentMap map[string]interface{},
	providerConfigKey string,
	providerConfigObject proto.Message,
) (isProviderConfigLoaded bool, err error)

LoadProviderConfig loads a provider config from the stack input map into a proto message.

Types

This section is empty.

Directories

Path Synopsis

Jump to